@@ -8,7 +8,7 @@ import time
 import uuid
 from collections import OrderedDict
 
-from wzdx.tools import date_tools, polygon_tools, wzdx_translator
+from wzdx.tools import date_tools, polygon_tools, wzdx_translator, cdot_geospatial_api
 from wzdx.util.collections import PathDict
 
 PROGRAM_NAME = 'PlannedEventsRawToStandard'
@@ -36,7 +36,7 @@ def main():
 
     generated_files_list = []
     for message in generated_messages:
-        output_path = f"{output_dir}/standard_568_{message['event']['source']['id']}_{round(message['rtdh_timestamp'])}_{message['event']['detail']['direction']}.json"
+        output_path = f"{output_dir}/standard_planned_event_{message['event']['source']['id']}.json"
         open(output_path, 'w+').write(json.dumps(message, indent=2))
         generated_files_list.append(output_path)
 
@@ -74,7 +74,7 @@ def generate_standard_messages_from_string(input_file_contents):
 
 
 # TODO: Integrate Category
-def is_incident(msg):
+def is_incident_wz(msg):
     id = msg.get('properties', {}).get('id', '')
     type = msg.get('properties', {}).get('type', '')
     # category = msg.get('properties', {}).get('Category')
@@ -86,13 +86,7 @@ def is_incident(msg):
 
 def generate_raw_messages(message_string):
     msg = json.loads(message_string)
-    messages = []
-
-    separated_messages = expand_event_directions(msg)
-    for indiv_msg in separated_messages:
-        # add any validation or checks here
-        messages.append(indiv_msg)
-    return messages
+    return expand_event_directions(msg)
 
 
 # Break event into
@@ -121,7 +115,7 @@ def expand_event_directions(message):
 
 
 def generate_rtdh_standard_message_from_raw_single(obj):
-    is_incident_msg, is_wz = is_incident(obj)
+    is_incident_msg, is_wz = is_incident_wz(obj)
     if is_incident_msg and not is_wz:
         id = obj.get('properties', {}).get('id')
         dir = obj.get('properties', {}).get('direction')
@@ -323,6 +317,38 @@ def create_description(name, roadName, startMarker, endMarker, typeOfWork, start
     return f"Event {name}, on {roadName}, between mile markers {startMarker} and {endMarker}. {typeOfWork}. Running between {startTime} and {endTime}"
 
 
+def get_improved_geometry(coordinates):
+    startPoint = coordinates[0]
+    endPoint = coordinates[-1]
+
+    startRouteParams = cdot_geospatial_api.get_route_and_measure(startPoint)
+    endRouteParams = cdot_geospatial_api.get_route_and_measure(endPoint)
+
+    if not startRouteParams or not endRouteParams:
+        logging.info(
+            "1 or more routes not found, not generating improved geometry")
+        return coordinates
+    if startRouteParams['Route'] != endRouteParams['Route']:
+        logging.info("Routes did not match, not generating improved geometry")
+        return coordinates
+
+    initialDirection = polygon_tools.get_road_direction_from_coordinates(
+        coordinates)
+    newCoordinates = cdot_geospatial_api.get_route_between_measures(
+        startRouteParams['Route'],
+        startRouteParams['Measure'],
+        endRouteParams['Measure'])
+    finalDirection = polygon_tools.get_road_direction_from_coordinates(
+        newCoordinates)
+
+    # TODO: Implement Bi-directional carriageway
+    if initialDirection == REVERSED_DIRECTION_MAP.get(finalDirection):
+        newCoordinates.reverse()
+
+    return newCoordinates
+
+
+# isIncident is unused, could be useful later though
 def create_rtdh_standard_msg(pd, isIncident):
     description = pd.get('properties/travelerInformationMessage')
     if description == INVALID_EVENT_DESCRIPTION:
@@ -358,8 +384,11 @@ def create_rtdh_standard_msg(pd, isIncident):
     end_date = pd.get("properties/clearTime",
                       date_tools.parse_datetime_from_iso_string)
     if not end_date:
-        # Since there is no end date, assume still active, set end date in future
-        end_date = datetime.datetime.utcnow() + datetime.timedelta(hours=24)
+        # Since there is no end date, assume still active, set end date in future (or 1 day after start date)
+        if start_date > datetime.datetime.utcnow():
+            end_date = start_date + datetime.timedelta(hours=24)
+        else:
+            end_date = datetime.datetime.utcnow() + datetime.timedelta(hours=24)
 
     event_type, types_of_work = map_event_type(
         pd.get("properties/type", default=""))
@@ -383,9 +412,9 @@ def create_rtdh_standard_msg(pd, isIncident):
                 "id": pd.get("properties/id", default="") + '_' + direction,
                 "last_updated_timestamp": pd.get('properties/lastUpdated', date_tools.get_unix_from_iso_string, default=0),
             },
-            "geometry": coordinates,
+            "geometry": get_improved_geometry(coordinates),
             "header": {
-                "description": pd.get("properties/travelerInformationMessage", default=""),
+                "description": description,
                 "start_timestamp": date_tools.date_to_unix(start_date),
                 "end_timestamp": date_tools.date_to_unix(end_date),
             },
